@@ -1,4 +1,6 @@
 from .greet import greet
 from .nextprime import nextprime
 from .sol_ode import sol_ode
-from .data_import import data_import
\ No newline at end of file
+from .data_import import data_import
+from .curve_fit_ode import curve_fit_ode
+from .curve_fit import curve_fit
\ No newline at end of file
